==> haskell-configurator-ng-0.0.0.1-9-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-configurator-ng.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: configurator-ng
version: 0.0.0.1
id: configurator-ng-0.0.0.1-6bGP3LwGQ5wCpFUB9Qe2kn
key: configurator-ng-0.0.0.1-6bGP3LwGQ5wCpFUB9Qe2kn
license: BSD3
copyright: Copyright 2011 MailRank, Inc.
           Copyright 2011-2014 Bryan O'\''Sullivan
           Copyright 2015-2016 Leon P Smith
maintainer: Leon P Smith <leon@melding-monads.com>
stability: experimental
homepage: http://github.com/lpsmith/configurator-ng
synopsis: The next generation of configuration management
description:
    A configuration management library for programs and daemons.
    .
    Features include:
    .
    * A simple, but flexible, configuration language, supporting several
    of the most commonly needed types of data, along with
    interpolation of strings from the configuration or the system
    environment (e.g. @$(HOME)@).
    .
    * An @import@ directive allows the configuration of a complex
    application to be split across several smaller files, or common
    configuration data to be shared across several applications.
    .
    * An expressive applicative/monadic high-level parsing interface
    to gracefully scale to more complicated configuration needs,  with
    powerful diagnostic messaging mechanism.
    .
    For details of the configuration file format, see
    <http://hackage.haskell.org/packages/archive/configurator/latest/doc/html/Data-Configurator.html>.
category: Configuration, Data
author: Bryan O'\''Sullivan, Leon P Smith
exposed: True
indefinite: False
exposed-modules:
    Data.Configurator Data.Configurator.Config
    Data.Configurator.Config.Internal Data.Configurator.FromValue
    Data.Configurator.FromValue.Internal Data.Configurator.Parser
    Data.Configurator.Parser.Internal Data.Configurator.Types
hidden-modules: Data.Configurator.Config.Implementation
                Data.Configurator.Parser.Implementation
                Data.Configurator.FromValue.Implementation Data.Configurator.Syntax
                Data.Configurator.Types.Internal
abi: 80c9f38a9e69bd0b3c95656617aa6cb7
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/configurator-ng-0.0.0.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/configurator-ng-0.0.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/configurator-ng-0.0.0.1
hs-libraries: HSconfigurator-ng-0.0.0.1-6bGP3LwGQ5wCpFUB9Qe2kn
depends:
    attoparsec-0.13.2.2-7ibVGq5lT2YZvA4JzOejy base-4.10.1.0
    bytestring-0.10.8.2 critbit-0.2.0.0-IrxTqlLjinLJzhO1nNItgR
    dlist-0.8.0.3-3sLvqWTqZxIC2tgTx4QBVJ directory-1.3.0.2
    data-ordlist-0.4.7.0-HY9GJ9QjrmJEtSDOUJy6x9
    hashable-1.2.6.1-6LeHpYZ4iRgEy9P36eCQfR
    scientific-0.3.5.2-912lci9Mxyc8ladEwh7DIT
    text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj
    unix-compat-0.4.3.1-9X6l1OQmDE7ClflprogzfQ
    unordered-containers-0.2.8.0-YOGDwOwys3HjU5i3g27KB
abi-depends: attoparsec-0.13.2.2-7ibVGq5lT2YZvA4JzOejy=9052f5e4288ee3b7fc66a1ba329f6d05
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             critbit-0.2.0.0-IrxTqlLjinLJzhO1nNItgR=394ac3502c419d411efd11e7b61e9046
             dlist-0.8.0.3-3sLvqWTqZxIC2tgTx4QBVJ=478549693a66e61496f47353d337a8f9
             directory-1.3.0.2=7b913664ccd770192b307d7c4c6817cc
             data-ordlist-0.4.7.0-HY9GJ9QjrmJEtSDOUJy6x9=ff263aed6f66b05a0b0255e129dadda4
             hashable-1.2.6.1-6LeHpYZ4iRgEy9P36eCQfR=e2c3f4e35e60b5547d3e7a8c501ca6de
             scientific-0.3.5.2-912lci9Mxyc8ladEwh7DIT=404255989f714abfb5b09cf0823e534e
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=b7726d921cac66adc5c8f9f66f5b25f0
             unix-compat-0.4.3.1-9X6l1OQmDE7ClflprogzfQ=345a389dfaa60cac4e76e74a938e5e3c
             unordered-containers-0.2.8.0-YOGDwOwys3HjU5i3g27KB=1ae4406c8abf6f6a305796d42b6e1b7b
haddock-interfaces: /usr/share/doc/haskell-configurator-ng/html/configurator-ng.haddock
haddock-html: /usr/share/doc/haskell-configurator-ng/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-configurator-ng-0.0.0.1-21-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-configurator-ng.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: configurator-ng
version: 0.0.0.1
id: configurator-ng-0.0.0.1-FuHhJjoJsVI881HpkPmlUE
key: configurator-ng-0.0.0.1-FuHhJjoJsVI881HpkPmlUE
license: BSD3
copyright: Copyright 2011 MailRank, Inc.
           Copyright 2011-2014 Bryan O'\''Sullivan
           Copyright 2015-2016 Leon P Smith
maintainer: Leon P Smith <leon@melding-monads.com>
stability: experimental
homepage: http://github.com/lpsmith/configurator-ng
synopsis: The next generation of configuration management
description:
    A configuration management library for programs and daemons.
    .
    Features include:
    .
    * A simple, but flexible, configuration language, supporting several
    of the most commonly needed types of data, along with
    interpolation of strings from the configuration or the system
    environment (e.g. @$(HOME)@).
    .
    * An @import@ directive allows the configuration of a complex
    application to be split across several smaller files, or common
    configuration data to be shared across several applications.
    .
    * An expressive applicative/monadic high-level parsing interface
    to gracefully scale to more complicated configuration needs,  with
    powerful diagnostic messaging mechanism.
    .
    For details of the configuration file format, see
    <http://hackage.haskell.org/packages/archive/configurator/latest/doc/html/Data-Configurator.html>.
category: Configuration, Data
author: Bryan O'\''Sullivan, Leon P Smith
exposed: True
indefinite: False
exposed-modules:
    Data.Configurator Data.Configurator.Config
    Data.Configurator.Config.Internal Data.Configurator.FromValue
    Data.Configurator.FromValue.Internal Data.Configurator.Parser
    Data.Configurator.Parser.Internal Data.Configurator.Types
hidden-modules: Data.Configurator.Config.Implementation
                Data.Configurator.Parser.Implementation
                Data.Configurator.FromValue.Implementation Data.Configurator.Syntax
                Data.Configurator.Types.Internal
abi: 877de2dbc41912e5af193cc773a718ea
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/configurator-ng-0.0.0.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/configurator-ng-0.0.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/configurator-ng-0.0.0.1
hs-libraries: HSconfigurator-ng-0.0.0.1-FuHhJjoJsVI881HpkPmlUE
depends:
    attoparsec-0.13.2.2-edlJ1qiIMBKPe2fnELys4 base-4.10.1.0
    bytestring-0.10.8.2 critbit-0.2.0.0-9KeHgi493HFLcn9NYqojN0
    dlist-0.8.0.4-8Td44GecKNEJmy7QK3HIQc directory-1.3.0.2
    data-ordlist-0.4.7.0-HY9GJ9QjrmJEtSDOUJy6x9
    hashable-1.2.7.0-D1kf6WO5TlN7xk82E4ZIan
    scientific-0.3.5.2-6cyGrFW0qofJtQe5gZMBGX
    text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz
    unix-compat-0.4.3.1-9X6l1OQmDE7ClflprogzfQ
    unordered-containers-0.2.9.0-GWvuj0HLmUnDmBShmJCvae
abi-depends: attoparsec-0.13.2.2-edlJ1qiIMBKPe2fnELys4=923ea4b48e3ff86a32743bf7d135ea3e
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             critbit-0.2.0.0-9KeHgi493HFLcn9NYqojN0=8a433fa5a6e2846994598b078813ac5f
             dlist-0.8.0.4-8Td44GecKNEJmy7QK3HIQc=891025a77d043cfd28f763ce7f5a4b16
             directory-1.3.0.2=7b913664ccd770192b307d7c4c6817cc
             data-ordlist-0.4.7.0-HY9GJ9QjrmJEtSDOUJy6x9=ff263aed6f66b05a0b0255e129dadda4
             hashable-1.2.7.0-D1kf6WO5TlN7xk82E4ZIan=7c14723fffdda860d330f4ccf53597f4
             scientific-0.3.5.2-6cyGrFW0qofJtQe5gZMBGX=7aedff29b89e83530bb1e2cdf3ff8b50
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
             unix-compat-0.4.3.1-9X6l1OQmDE7ClflprogzfQ=345a389dfaa60cac4e76e74a938e5e3c
             unordered-containers-0.2.9.0-GWvuj0HLmUnDmBShmJCvae=b402656649e5f5df6537cabd8124c4af
haddock-interfaces: /usr/share/doc/haskell-configurator-ng/html/configurator-ng.haddock
haddock-html: /usr/share/doc/haskell-configurator-ng/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
